==> Paws-0.35.tar.gz: Paws-0.35/lib/Paws/Glue/DeleteDevEndpoint.pm <==

package Paws::Glue::DeleteDevEndpoint;
  use Moose;
  has EndpointName => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteDevEndpoint');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Glue::DeleteDevEndpointResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Glue::DeleteDevEndpoint - Arguments for method DeleteDevEndpoint on Paws::Glue

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteDevEndpoint on the 
AWS Glue service. Use the attributes of this class
as arguments to method DeleteDevEndpoint.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeleteDevEndpoint.

As an example:

  $service_obj->DeleteDevEndpoint(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> EndpointName => Str

The name of the DevEndpoint.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteDevEndpoint in L<Paws::Glue>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.37.tar.gz: Paws-0.37/lib/Paws/Glue/DeleteDevEndpoint.pm <==

package Paws::Glue::DeleteDevEndpoint;
  use Moose;
  has EndpointName => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteDevEndpoint');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::Glue::DeleteDevEndpointResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Glue::DeleteDevEndpoint - Arguments for method DeleteDevEndpoint on L<Paws::Glue>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteDevEndpoint on the
L<AWS Glue|Paws::Glue> service. Use the attributes of this class
as arguments to method DeleteDevEndpoint.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeleteDevEndpoint.

=head1 SYNOPSIS

    my $glue = Paws->service('Glue');
    my $DeleteDevEndpointResponse = $glue->DeleteDevEndpoint(
      EndpointName => 'MyGenericString',

    );

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/glue/DeleteDevEndpoint>

=head1 ATTRIBUTES


=head2 B<REQUIRED> EndpointName => Str

The name of the DevEndpoint.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteDevEndpoint in L<Paws::Glue>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
